#!/bin/sh

PIDFILE=/var/run/ntpd.pid
USER=nobody
GROUP=nobody
NTP_SERVERS=`grep -e ^server /etc/ntp.conf | cut -d " " -f 2 | xargs`

stop()
{
    kill `cat $PIDFILE` && rm $PIDFILE
}

start()
{
    DO_INITIAL_SKEW=$1
    if [ -e $PIDFILE ]; then
        echo ntpd already appears to be running.
        echo If not, please remove $PIDFILE, then try again.
    else
        if [ $DO_INITIAL_SKEW == 1 ]; then 
            # immediately slew the clock time, then exit
            # -b = step using the settimeofday function. The man page
            #      says that it should be called on startup, which this is
            ntpdate -b $NTP_SERVERS && hwclock --systohc
        fi
        # once that is completed, start ntpd
        # -u = change user (don't want to run as root)
        # -p = record pid in pidfile
        ntpd -u $USER:$GROUP -p $PIDFILE
    fi

}

restart()
{
    stop
    start 0
}

if [ "$1" ]; then
    case "$1" in
        start)
            start 1
            ;;
        stop)
            stop
            ;;
        restart)
            restart
            ;;
        *)
            echo "Usage: $0 [ start | stop | restart ]"
            exit 1
            ;;
    esac
else 
    # No command passed in, assume start, with initial skew
    start 1
fi
