#!/bin/sh
# @file
#
# @brief Script load and unload the Sixnet iodb/stbus driver
#
# Copyright 2014 Red Lion Controls, Inc.
# All Rights reserved.
#
#
log="/dev/null"
#log="/var/log/`basename $0`"

#
# Unload the Sixnet iodb/stbus driver
#
stop()
{
    #
    # Wait for the driver to be unloaded.
    #
    echo "Unloading the stbus driver" >> $log
    /usr/local/bin/sixnetDriver unload
    /etc/driver_stat stbus unload 10
    if [ $? -ne 0 ]; then
        echo "Timed out waiting for stbus driver to be unloaded" >> $log
    else
        echo "Stbus driver unloaded" >> $log
    fi
}

#
# Load the iodb/stbus driver
#
start()
{
    #
    # Wait for the stbus driver to be loaded.
    #
    echo "Loading the stbus driver" >> $log
    /usr/local/bin/sixnetDriver load
    /etc/driver_stat stbus loaded 10
    if [ $? -ne 0 ]; then
        echo "Timed out waiting for stbus driver to be loaded" >> $log
    else
        echo "Stbus driver loaded" >> $log
    fi
}

#
# Check to see if a command was passed into the script.
#
if [ "$1" ]; then
    case "$1" in
        start)
            start
            ;;
        stop)
            stop
            ;;
        *)
            echo "Usage: stbus [ start | stop ]"
            exit 1
            ;;
    esac
    exit
fi

# No command passed in, assume start
start
