#!/bin/sh

stop() {
    killall sshd
    echo Stopped sshd
}

start() {
    # This conditional handles switches, which export variables via mscfg
    # and IPms, which do not (but store all their things in /etc/stacfg)
    if [ -e /usr/local/bin/mscfg ]; then
        . /usr/local/bin/mscfg
    else 
        MSCFG_DIR=/etc/stacfg
    fi

    # if this file exists, it's a switch, assume switch semantics
    if [ -e $MSCFG_DIR/main.config ]; then
        # Don't generate keys if we're in production
        /usr/local/bin/sxnetset -g in_prod >& /dev/null
        if [ $? -eq 1 ]; then
            # Check to see if we need keys
            /usr/local/bin/required_ssh_keys_exist
            if [ $? -eq 0 ]; then
                # We need host keys
                /usr/local/bin/generateSSHKeys
                # We've generated keys at least once, touch our done file.
                touch /etc/ssh/.generatedSSHKeys
            fi
        fi

        line=`grep terminal $MSCFG_DIR/main.config`
        sshd_enable=`echo $line|grep ssh`
        both_enable=`echo $line|grep both`
        if [ -n "$sshd_enable" -o -n "$both_enable" ]; then
            /usr/sbin/sshd
            echo Started sshd
        fi 
    # else assume IPm semantics
    elif [ -e $MSCFG_DIR/general.config ]; then 
        line=`grep 'enable ssh' $MSCFG_DIR/general.config`
        sshd_enable=`echo $line|grep 1`
        if [ -n "$sshd_enable" ]; then
            /usr/sbin/sshd
	    touch /tmp/ssh_enabled
            echo Started sshd
	else
            rm /tmp/ssh_enabled
        fi 
    else
    # no idea
        echo I can find neither a main.config or a general.config.
        echo What kind of unit are you?
    fi
}

if [ "$1" ]; then
    case "$1" in
        start)
            start
            ;;
        stop)
            stop
            ;;
        restart)
            stop
            start
            ;;
    esac;
    exit;
fi
#  no command passed in, assume start
#
start
