#!/bin/sh
# @file
#
# @brief Script to start/stop core Sixnet applications not started by init.
#
# Copyright 2013 Red Lion Controls, Inc.
# All Rights reserved.
#
#
log="/dev/null"
#log="/var/log/`basename $0`"

#
# This only stops the sixnet applications that are not
# started by init.
#
stop()
{
    echo "Stopping Sixnet Applications" >> $log
    monit -g sixnet_core stop

    #
    # Check to see if this is being called from an rc kill script
    # used when changing run levels.
    #
    echo $0 | grep -q "K[0..9][0..9]IpmApps.sh"
    if [ $? == 0 ]; then
        #
        # Remove the spec_feat_sync and sxmanager_warm_boot files
        # in /tmp.
        #
        rm -f /tmp/spfeat_sync_file
        rm -f /tmp/sxmanager_warm_boot
    else
        echo "Not removing sixnet tmp files"
    fi
}

#
# Load the iodb/stbus driver and start all the Sixnet applications
# that are not started by init.
#
start()
{
    #
    # Wait for the stbus driver to be loaded.
    #
    /etc/driver_stat stbus loaded 10
    if [ $? -ne 0 ]; then
        echo "Timed out waiting for stbus driver to be loaded" >> $log
    else
        echo "Starting Sixnet Applications" >> $log
        #
        # sxhbtwdg must be started before anything else because it
        # sets up shared memory that is used by some of the other
        # sixnet applications.
        #
        monit start sxhbtwdg
        monit start sxmanager
        monit start sxspecfeat

        # Give the above processes an chance to finish starting
        # before starting the other Sixnet core processes.

        sleep 2

        monit start sxetherpeer
        monit start sxportload
        monit start sxtagload
        monit start sxredundancy
        monit start sxmbeth_client
        monit start sxpeerlink
        monit start sxmonitor
        monit start soemanager
    fi
}

#
# This only restarts the sixnet applications that
# are not started by init.
#
restart()
{
    stop
    start
}

#
# Check to see if a command was passed into the script.
#
if [ "$1" ]; then
    case "$1" in
        start)
            start
            ;;
        stop)
            stop
            ;;
        restart)
            restart
            ;;
        *)
            echo "Usage: IpmApps [ start | stop | restart ]"
            exit 1
            ;;
    esac
    exit
fi

# No command passed in, assume start
start
