#!/usr/bin/perl
#
# Copyright 2012 SIXNET, LLC
#
#  Notice: This document contains proprietary, confidential information
#  owned by SIXNET, LLC and is protected as an unpublished work under
#  the Copyright Law of the United States. No part of this document may
#  be copied, disclosed to others or used for any purpose without the
#  written permission of Digitronics Inventioneering Corporation.


#
# Package with general logging functions
#

package Sixnet::SVM::Log;

require strict;
require warnings;
require Exporter;

our @ISA = qw(Exporter);
our @EXPORT = qw(setPrintFlag setProgName setSyslogFlag syslogAndPrint);

my $progName;
my $printFlag=0;
my $syslogFlag=1;

##
# Set our progName variable
#
# @param program - name of program
#
# @return base name of program on success
# @return undef on failure
#
sub setProgName($)
{
    my  ($prog) = @_;

    if (defined($prog)) {
        $progName = `basename $prog`;
        chomp($progName);
    }
    return $progName;
}

##
# Enable or disable print logging
#
# @param flag - 0 to disable, 1 to enable.
#
# @return 0 on success.
# @return -1 on failure.
#
sub setPrintFlag($)
{
    my ($flag) = @_;
    my $retVal = -1;

    if (($flag == 0) || ($flag == 1)) {
        $printFlag = $flag;
        $retVal = 0;
    }
    return $retVal;
}

##
# Enable or disable syslog logging
#
# @param flag - 0 to disable, 1 to enable.
#
# @return 0 on success.
# @return -1 on failure.
#
sub setSyslogFlag($)
{
    my ($flag) = @_;
    my $retVal = -1;

    if (($flag == 0) || ($flag == 1)) {
        $syslogFlag = $flag;
        $retVal = 0;
    }
    return $retVal;
}

##
# Log message to both stdout and to syslog.
#
# @param msg - message to log
# @param p   - log level for message.
#
# @return 0 if success
# @return -1 if failure
#
sub syslogAndPrint(@)
{
    my ($mess, $p) = @_;
    my $retVal = 0;

    chomp($mess);

    #
    # print first before addind esc chars
    #
    if ($printFlag == 1) {
        if (!print("$progName: $mess\n")) {
            $retVal = -1;
        }
    }

    if ($syslogFlag == 1) {
        $mess =~ s/\"/\\\"/g;
        $mess =~ s/\n//g;
        $mess =~ s/\r//g;

        if (defined($p) && $p =~ /[0-9]/)
        {
            system("logger -t \"$progName\[$$\]\" -p $p \"$mess\" ");
            if ($?) {
                $retVal = -1;
            }
        }
        else
        {
            system("logger -t \"$progName\[$$\]\" \"$mess\"");
            if ($?) {
                $retVal = -1;
            }
        }
    }

    return $retVal;
}

sub logInit()
{
    return 1;
}

return logInit();
