#!/bin/sh
#set -x
log () { true; }
logf="/var/log/`basename $0`"
#log () if [ $# -eq 0 ] ; then cat ; else echo -e "`date`: $*" ; fi >>$logf

SNTP=/usr/bin/sntp
HWCLOCK=/sbin/hwclock
CONFIG_FILE=/etc/stacfg/general.config
CLOCKSTATUS=/var/run/clock.status

##
# Set the clock sync status bit in file and register.
#
setSync ( ) {
    if [ "$1" = "1" -o "$1" = "0" ] ; then
        echo $1 > $CLOCKSTATUS
        log "Updating the clock sync bit"
        # Call the binary that will read to which discrete to write,
        # and set it correctly.
        sxclockstat $1
    else
        echo setSync: bad parameter $1 >&2
    fi
}

#
# Check to see if a file exists, and exit if it does not.
#
FileExists ( )
{
    fileName=$1
    #
    # Make sure the file exists
    #
    if [ ! -f $fileName ] ; then
        log "$FileName not found, exiting script"
        exit
    fi
    return 0
}


#
# Get the ntp server ip address
#
SntpGetServer ( )
{
    #
    # Get from /etc/stacfg/general.config
    #
    srv=`grep ntp_server $CONFIG_FILE | tr "=" " " | cut -d " " -f 2`

    log "Time server is $srv"

    if [ -z "$srv" -o "$srv" = "none" ] ; then
        log "Couldn't figure out time server"
        return 1
    fi
    return 0
}

#
# Get the ntp server ip address
#
SntpGetInterval ( )
{
    #
    # Get from /etc/stacfg/general.config
    #
    ntpInterval=`grep ntp_interval $CONFIG_FILE | tr "=" " " | cut -d " " -f 2`


    if [ -z "$ntpInterval" ] ; then
        #
        # This is to make sure that this change works with older toolkit versions
        # that do not provide this parameter.  We default to 5 minutes because
        # that is the value we use in older firmware.
        #
        ntpInterval=5;
        log "Defaulting ntp interval to 5 minutes"
    fi

    if [ $ntpInterval -ge 5 ] && [ $ntpInterval -le 1440 ]; then
        log "Ntp request interval: $ntpInterval minutes"
        #
        # Convert the time from minutes to seconds

        ntpInterval=`expr $ntpInterval \\* 60`
        return 0
    fi

    log "Invalid ntp request interval: $ntpInterval"
    return 1
}

CheckConfig ( )
{
    # initialize status to 0 (clock not synchronized)
    echo 0 > $CLOCKSTATUS

    FileExists $CONFIG_FILE
    retVal=$?

    if [ $retVal = 1 ] ; then
        exit 1
    fi

    FileExists $SNTP
    retVal=$?

    if [ $retVal = 1 ] ; then
        exit 1
    fi

    FileExists $HWCLOCK
    retVal=$?

    if [ $retVal = 1 ] ; then
        exit 2
    fi

    SntpGetServer
    retVal=$?

    if [ $retVal = 1 ] ; then
        exit 3
    fi

    SntpGetInterval
    retVal=$?

    if [ $retVal = 1 ] ; then
        exit 3
    fi

    return $retVal
}

#
# Update the hardware clock
#
HwClockSet ( )
{
    $HWCLOCK --systohc
    if [ $? = 0 ] ; then
        log The hwclock was set to `date`
    else
        log Failed to set the hwclock
    fi
}

#
# Get the time from an ntpserver and update the local clocks.
#
#   1. Update the system clock using sntp.
#   2. Update the real-time clock.
#   3. Update the clock sync bit.
#
UpdateClock ( )
{
    #
    # Get the time and date from the server using sntp
    #
    $SNTP -S $srv 2>&1 >/dev/null
    retVal=$?
    if [ $retVal != 0 ] ; then
        #
        # sntp returned an error and the time was not updated.
        #
        setSync 0

        #
        # wait Sleep Time seconds before retrying.
        #
        log "NTP Server did not respond ... "
    else
        #
        # The time was updated so update the clock sync bit.
        #
        setSync 1

        #
        # Update the hardware clock with the new time.
        #
        HwClockSet
    fi

    return $retVal
}


#
# Main function
#
log "\n`date`\n$*"

# reset ntp sync bit
echo 0 > $CLOCKSTATUS

CheckConfig

#
# Attempt to update the clock, and then sleep
# for the configured interval.
#
while true ; do
    UpdateClock
    sleep $ntpInterval
done

date | log
